@@ -25,6 +25,10 @@ function test_bluer_sbc_help() {
         "@sbc lepton capture" \
         "@sbc lepton preview" \
         \
+        "@sbc parts" \
+        "@sbc parts adjust" \
+        "@sbc parts cd" \
+        \
         "@sbc pypi" \
         "@sbc pypi browse" \
         "@sbc pypi build" \
@@ -32,6 +36,9 @@ function test_bluer_sbc_help() {
         \
         "@sbc pytest" \
         \
+        "@sbc rpi" \
+        "@sbc rpi fake_display" \
+        \
         "@sbc scroll_phat_hd" \
         "@sbc scroll_phat_hd validate" \
         \
