@@ -2,9 +2,9 @@ NAME = "bluer_sbc"
 
 ICON = "🌀"
 
-DESCRIPTION = f"{ICON} AI for single board computers."
+DESCRIPTION = f"{ICON} AI for single board computers and related designs."
 
-VERSION = "8.153.1"
+VERSION = "9.69.1"
 
 REPO_NAME = "bluer-sbc"
 
